@@ -9,7 +9,7 @@
     This file is part of mss.
 
     :copyright: Copyright 2017 Reimar Bauer, Joern Ungermann
-    :copyright: Copyright 2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2017-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,7 +26,8 @@
 """
 
 import os
-import tempfile
+import fs
+from fs.tempfs import TempFS
 
 try:
     import git
@@ -36,8 +37,17 @@ else:
     repo = git.Repo(search_parent_directories=True)
     SHA = repo.head.object.hexsha
 
+SERVER_CONFIG_FILE = u"mss_wms_settings.py"
+ROOT_FS = TempFS(identifier="mss{}".format(SHA))
+ROOT_DIR = ROOT_FS.root_path
 
-BASE_DIR = os.path.join(tempfile.gettempdir(), "mss{}".format(SHA))
-DATA_DIR = os.path.join(BASE_DIR, 'testdata')
-SERVER_CONFIG_FILE = os.path.join(BASE_DIR, "mss_wms_settings.py")
-os.environ["MSS_CONFIG_PATH"] = BASE_DIR
+if not ROOT_FS.exists(u"mss/testdata"):
+    ROOT_FS.makedirs(u"mss/testdata")
+SERVER_CONFIG_FS = fs.open_fs(os.path.join(ROOT_DIR, u'mss'))
+DATA_FS = fs.open_fs(os.path.join(ROOT_DIR, u'mss/testdata'))
+
+os.environ["MSS_CONFIG_PATH"] = SERVER_CONFIG_FS.root_path
+SERVER_CONFIG_FILE_PATH = os.path.join(SERVER_CONFIG_FS.root_path, SERVER_CONFIG_FILE)
+
+# we keep DATA_DIR until we move netCDF4 files to pyfilesystem2
+DATA_DIR = DATA_FS.root_path
