@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -50,6 +50,11 @@ class MissionSupportSystemDefaultConfig(object):
     Do not change any value for good reasons.
     Your values can be set in your personal mss_settings.json file
     """
+    # Default for general filepicker. Pick "default", "qt", or "fs"
+    filepicker_default = "default"
+
+    # dir where mss output files are stored
+    data_dir = u"~/mssdata"
 
     # layout of different views, with immutable they can't resized
     layout = {"topview": (963, 702),
