@@ -4,13 +4,13 @@
     mslib.msui.mpl_qtwidget
     ~~~~~~~~~~~~~~~~~~~~~~~
 
-    Definitions of Matplotlib widgets for Qt4 Designer.
+    Definitions of Matplotlib widgets for Qt Designer.
 
     This file is part of mss.
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,42 +32,39 @@ from __future__ import division
 # 'Matplotlib for Python Developers'.
 
 from datetime import datetime
-
+import os
+import six
 import logging
-from mslib.utils import config_loader
-from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
+
 # related third party imports
 import numpy as np
+import matplotlib
 import matplotlib.pyplot as plt
+from fs import open_fs
+from fslib.fs_filepicker import getSaveFileNameAndFilter
+
+from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT, FigureCanvasQTAgg
 
 # local application imports
+from mslib import thermolib
+from mslib.utils import config_loader, FatalUserError
+from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
+from mslib.msui.mss_qt import QtGui
 from mslib.msui import mpl_pathinteractor as mpl_pi
 from mslib.msui import mpl_map
 from mslib.msui import trajectory_item_tree as titree
-from mslib import thermolib
+from mslib.msui.icons import icons
+from mslib.msui.mss_qt import QtCore, QtWidgets
 
 
-# Python Qt4 bindings for GUI objects
-from mslib.msui.mss_qt import QtCore, QtWidgets, FigureCanvas, NavigationToolbar
+PIL_IMAGE_ORIGIN = "upper"
+LAST_SAVE_DIRECTORY = config_loader(dataset="data_dir", default=mss_default.data_dir)
 
-# Matplotlib Figure object
-from matplotlib.figure import Figure
-
-# With Matplotlib 1.2, PIL images are rotated differently when plotted with
-# imshow(). See Basemap __init__.py file, in which the same issue occurs
-# (https://github.com/matplotlib/basemap/pull/52). (mr, 08Feb2013)
-from matplotlib import __version__ as _matplotlib_version
-
-if _matplotlib_version >= '1.2':
-    # orientation of arrays returned by pil_to_array
-    # changed (https://github.com/matplotlib/matplotlib/pull/616)
-    PIL_image_origin = "upper"
-else:
-    PIL_image_origin = "lower"
+matplotlib.rcParams['savefig.directory'] = LAST_SAVE_DIRECTORY
 
 
-class MplCanvas(FigureCanvas):
-    """Class to represent the FigureCanvas widget.
+class MplCanvas(FigureCanvasQTAgg):
+    """Class to represent the FigureCanvasQTAgg widget.
 
     Main axes instance has zorder 99 (important when additional
     axes are added).
@@ -75,20 +72,19 @@ class MplCanvas(FigureCanvas):
 
     def __init__(self):
         # setup Matplotlib Figure and Axis
-        self.fig = Figure(facecolor="w")  # 0.75
+        self.fig = matplotlib.figure.Figure(facecolor="w")  # 0.75
         self.ax = self.fig.add_subplot(111, zorder=99)
         self.default_filename = "_image"
 
         # initialization of the canvas
-        FigureCanvas.__init__(self, self.fig)
+        super(MplCanvas, self).__init__(self.fig)
 
         # we define the widget as expandable
-        FigureCanvas.setSizePolicy(self,
-                                   QtWidgets.QSizePolicy.Expanding,
-                                   QtWidgets.QSizePolicy.Expanding)
+        super(MplCanvas, self).setSizePolicy(
+            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
 
         # notify the system of updated policy
-        FigureCanvas.updateGeometry(self)
+        super(MplCanvas, self).updateGeometry()
 
     def get_default_filename(self):
         result = self.basename + self.default_filename
@@ -152,7 +148,7 @@ class MplWidget(QtWidgets.QWidget):
 
     def __init__(self, parent=None):
         # initialization of Qt MainWindow widget
-        QtWidgets.QWidget.__init__(self, parent)
+        super(MplWidget, self).__init__(parent)
 
         # set the canvas to the Matplotlib widget
         self.canvas = MplCanvas()
@@ -167,12 +163,283 @@ class MplWidget(QtWidgets.QWidget):
         self.setLayout(self.vbl)
 
 
+def _getSaveFileName(parent, title="Choose a filename to save to", filename=u"test.png",
+                     filters=u" Images (*.png)"):
+    _dirname, _name = os.path.split(filename)
+    _dirname = os.path.join(_dirname, "")
+    return getSaveFileNameAndFilter(parent, fs_url=_dirname, file_pattern=filters,
+                                    title=title, default_filename=_name, show_save_action=True)
+
+
+save_figure_original = NavigationToolbar2QT.save_figure
+
+
+def save_figure(self, *args):
+    picker_default = config_loader(dataset="filepicker_default",
+                                   default=mss_default.filepicker_default)
+    picker_type = config_loader(dataset="filepicker_matplotlib",
+                                default=picker_default)
+    if picker_type in ["default", "qt"]:
+        save_figure_original(self, *args)
+    elif picker_type == "fs":
+        filetypes = self.canvas.get_supported_filetypes_grouped()
+        sorted_filetypes = list(six.iteritems(filetypes))
+        sorted_filetypes.sort()
+        startpath = matplotlib.rcParams.get('savefig.directory', LAST_SAVE_DIRECTORY)
+        startpath = os.path.expanduser(startpath)
+        start = os.path.join(startpath, self.canvas.get_default_filename())
+        filters = []
+        for name, exts in sorted_filetypes:
+            exts_list = " ".join(['*.%s' % ext for ext in exts])
+            filter = '%s (%s)' % (name, exts_list)
+            filters.append(filter)
+
+        fname, filter = _getSaveFileName(self.parent,
+                                         title="Choose a filename to save to",
+                                         filename=start, filters=filters)
+        if fname is not None:
+            if not fname.endswith(filter[1:]):
+                fname = filter.replace('*', fname)
+            if startpath == '':
+                # explicitly missing key or empty str signals to use cwd
+                matplotlib.rcParams['savefig.directory'] = startpath
+            else:
+                # save dir for next time
+                savefig_dir = os.path.dirname(six.text_type(fname))
+                matplotlib.rcParams['savefig.directory'] = savefig_dir
+            try:
+                _dirname, _name = os.path.split(fname)
+                _fs = open_fs(_dirname)
+                with _fs.open(_name, 'wb') as source:
+                    self.canvas.print_figure(source, format=filter.replace('*.', ''))
+            except Exception as e:
+                QtWidgets.QMessageBox.critical(
+                    self, "Error saving file", six.text_type(e),
+                    QtWidgets.QMessageBox.Ok, QtWidgets.QMessageBox.NoButton)
+    else:
+        raise FatalUserError("Unknown file picker type '{}'".format(picker_type))
+
+
+# Patch matplotlib function
+NavigationToolbar2QT.save_figure = save_figure
+
+
+class NavigationToolbar(NavigationToolbar2QT):
+    # only display the buttons we need
+
+    def __init__(self, canvas, parent, sideview=False, coordinates=True):
+        if sideview:
+            self.toolitems = [
+                _x for _x in NavigationToolbar2QT.toolitems if _x[0] in ('Save',)]
+        else:
+            self.toolitems = [
+                _x for _x in NavigationToolbar2QT.toolitems if
+                _x[0] in ('Home', 'Back', 'Forward', 'Pan', 'Zoom', 'Save') or _x[0] is None]
+
+        self.sideview = sideview
+        super(NavigationToolbar, self).__init__(canvas, parent, coordinates)
+        self.canvas = canvas
+        self._idMotion = None
+
+    def insert_wp(self, *args):
+        """Activate the pan/zoom tool. pan with left button, zoom with right"""
+        # set the pointer icon and button press funcs to the
+        # appropriate callbacks
+
+        if self._active == 'INSERT_WP':
+            self._active = None
+        else:
+            self._active = 'INSERT_WP'
+
+        if self._idPress is not None:
+            self._idPress = self.canvas.mpl_disconnect(self._idPress)
+            self.mode = ''
+
+        if self._idRelease is not None:
+            self._idRelease = self.canvas.mpl_disconnect(self._idRelease)
+            self.mode = ''
+
+        if self._idMotion is not None:
+            self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
+
+        if self._active:
+            self._idPress = self.canvas.mpl_connect(
+                'button_press_event', self.press_wp)
+            self._idRelease = self.canvas.mpl_connect(
+                'button_release_event', self.canvas.waypoints_interactor.button_release_insert_callback)
+            self.mode = 'insert waypoint'
+            self.canvas.widgetlock(self)
+        else:
+            self.canvas.widgetlock.release(self)
+
+        self.set_message(self.mode)
+        self._update_buttons_checked()
+
+    def delete_wp(self, *args):
+        """Activate the pan/zoom tool. pan with left button, zoom with right"""
+        # set the pointer icon and button press funcs to the
+        # appropriate callbacks
+
+        if self._active == 'DELETE_WP':
+            self._active = None
+        else:
+            self._active = 'DELETE_WP'
+        if self._idPress is not None:
+            self._idPress = self.canvas.mpl_disconnect(self._idPress)
+            self.mode = ''
+
+        if self._idRelease is not None:
+            self._idRelease = self.canvas.mpl_disconnect(self._idRelease)
+            self.mode = ''
+
+        if self._idMotion is not None:
+            self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
+
+        if self._active:
+            self._idPress = self.canvas.mpl_connect(
+                'button_press_event', self.press_wp)
+            self._idRelease = self.canvas.mpl_connect(
+                'button_release_event', self.canvas.waypoints_interactor.button_release_delete_callback)
+            self.mode = 'delete waypoint'
+            self.canvas.widgetlock(self)
+        else:
+            self.canvas.widgetlock.release(self)
+
+        for a in self.canvas.figure.get_axes():
+            a.set_navigate_mode(self._active)
+
+        self.set_message(self.mode)
+        self._update_buttons_checked()
+
+    def move_wp(self, *args):
+        """Activate the pan/zoom tool. pan with left button, zoom with right"""
+        # set the pointer icon and button press funcs to the
+        # appropriate callbacks
+
+        if self._active == 'MOVE_WP':
+            self._active = None
+        else:
+            self._active = 'MOVE_WP'
+
+        if self._idPress is not None:
+            self._idPress = self.canvas.mpl_disconnect(self._idPress)
+            self.mode = ''
+
+        if self._idRelease is not None:
+            self._idRelease = self.canvas.mpl_disconnect(self._idRelease)
+            self.mode = ''
+
+        if self._idMotion is not None:
+            self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
+
+        if self._active:
+            self._idPress = self.canvas.mpl_connect(
+                'button_press_event', self.press_wp)
+            self._idRelease = self.canvas.mpl_connect(
+                'button_release_event', self.canvas.waypoints_interactor.button_release_move_callback)
+            self._idMotion = self.canvas.mpl_connect(
+                'motion_notify_event', self.motion_wp)
+
+            self.mode = 'move waypoint'
+            self.canvas.widgetlock(self)
+        else:
+            self.canvas.widgetlock.release(self)
+
+        self.set_message(self.mode)
+        self._update_buttons_checked()
+
+    def pan(self, *args):
+        if self._idMotion is not None:
+            self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
+        NavigationToolbar2QT.pan(self, *args)
+
+    def zoom(self, *args):
+        if self._idMotion is not None:
+            self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
+        NavigationToolbar2QT.zoom(self, *args)
+
+    def motion_wp(self, event):
+        self.canvas.waypoints_interactor.motion_notify_callback(event)
+
+    def press_wp(self, event):
+        self.canvas.waypoints_interactor.button_press_callback(event)
+
+    def _init_toolbar(self):
+        self.basedir = os.path.join(matplotlib.rcParams['datapath'], 'images')
+        for text, tooltip_text, image_file, callback in self.toolitems:
+            if text is None:
+                self.addSeparator()
+            else:
+                a = self.addAction(self._icon(image_file + '.png'),
+                                   text, getattr(self, callback))
+                self._actions[callback] = a
+                if callback in ['zoom', 'pan']:
+                    a.setCheckable(True)
+                if tooltip_text is not None:
+                    a.setToolTip(tooltip_text)
+                if text == 'Subplots':
+                    a = self.addAction(self._icon("qt4_editor_options.png"),
+                                       'Customize', self.edit_parameters)
+                    a.setToolTip('Edit axis, curve and image parameters')
+        if self.sideview:
+            wp_tools = [('Mv WP', icons("32x32", "wp_move.png"), 'Move waypoints', 'move_wp')]
+        else:
+            wp_tools = [
+                ('Mv WP', icons("32x32", "wp_move.png"), 'Move waypoints', 'move_wp'),
+                ('Ins WP', icons("32x32", "wp_insert.png"), 'Insert waypoints', 'insert_wp'),
+                ('Del WP', icons("32x32", "wp_delete.png"), 'Delete waypoints', 'delete_wp'),
+            ]
+        self.addSeparator()
+        for text, img, tooltip_text, callback in wp_tools:
+            a = self.addAction(QtGui.QIcon(img), text, getattr(self, callback))
+            self._actions[callback] = a
+            a.setCheckable(True)
+            a.setToolTip(tooltip_text)
+
+        self.buttons = {}
+
+        # Add the x,y location widget at the right side of the toolbar
+        # The stretch factor is 1 which means any resizing of the toolbar
+        # will resize this label instead of the buttons.
+        if self.coordinates:
+            self.locLabel = QtWidgets.QLabel("", self)
+            self.locLabel.setAlignment(
+                QtCore.Qt.AlignRight | QtCore.Qt.AlignTop)
+            self.locLabel.setSizePolicy(
+                QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding,
+                                      QtWidgets.QSizePolicy.Ignored))
+            labelAction = self.addWidget(self.locLabel)
+            labelAction.setVisible(True)
+
+        # reference holder for subplots_adjust window
+        self.adj_window = None
+
+        # Esthetic adjustments - we need to set these explicitly in PyQt5
+        # otherwise the layout looks different - but we don't want to set it if
+        # not using HiDPI icons otherwise they look worse than before.
+
+        self.setIconSize(QtCore.QSize(24, 24))
+        self.layout().setSpacing(12)
+
+    def _update_buttons_checked(self):
+        # sync button checkstates to match active mode
+        if 'pan' in self._actions:
+            self._actions['pan'].setChecked(self._active == 'PAN')
+        if 'zoom' in self._actions:
+            self._actions['zoom'].setChecked(self._active == 'ZOOM')
+        if 'insert_wp' in self._actions:
+            self._actions['insert_wp'].setChecked(self._active == 'INSERT_WP')
+        if 'delete_wp' in self._actions:
+            self._actions['delete_wp'].setChecked(self._active == 'DELETE_WP')
+        self._actions['move_wp'].setChecked(self._active == 'MOVE_WP')
+
+
 class MplNavBarWidget(QtWidgets.QWidget):
     """Matplotlib canvas widget with navigation toolbar defined in Qt Designer"""
 
-    def __init__(self, parent=None, canvas=None):
+    def __init__(self, sideview=False, parent=None, canvas=None):
         # initialization of Qt MainWindow widget
-        QtWidgets.QWidget.__init__(self, parent)
+        super(MplNavBarWidget, self).__init__(parent)
 
         # set the canvas to the Matplotlib widget
         if canvas:
@@ -181,7 +448,7 @@ class MplNavBarWidget(QtWidgets.QWidget):
             self.canvas = MplCanvas()
 
         # instantiate the navigation toolbar
-        self.navbar = NavigationToolbar(self.canvas, self)
+        self.navbar = NavigationToolbar(self.canvas, self, sideview)
 
         # create a vertical box layout
         self.vbl = QtWidgets.QVBoxLayout()
@@ -522,12 +789,9 @@ class MplSideViewCanvas(MplCanvas):
 
         # Plot the new image in the image axes and adjust the axes limits.
         self.image = self.imgax.imshow(img, interpolation="nearest", aspect="auto",
-                                       origin=PIL_image_origin)
+                                       origin=PIL_IMAGE_ORIGIN)
         self.imgax.set_xlim(0, ix - 1)
-        if _matplotlib_version >= "1.2":
-            self.imgax.set_ylim(iy - 1, 0)
-        else:
-            self.imgax.set_ylim(0, iy - 1)
+        self.imgax.set_ylim(iy - 1, 0)
         self.draw()
         logging.debug("done.")
 
@@ -538,15 +802,15 @@ class MplSideViewWidget(MplNavBarWidget):
     """
 
     def __init__(self, parent=None):
-        super(MplSideViewWidget, self).__init__(parent=parent,
-                                                canvas=MplSideViewCanvas())
+        super(MplSideViewWidget, self).__init__(
+            sideview=True, parent=parent, canvas=MplSideViewCanvas())
         # Disable some elements of the Matplotlib navigation toolbar.
         # Available actions: Home, Back, Forward, Pan, Zoom, Subplots,
         #                    Customize, Save
         actions = self.navbar.actions()
         for action in actions:
             if action.text() in ["Home", "Back", "Forward", "Pan", "Zoom",
-                                 "Subplots", "Customize"]:
+                                 "Subplots", "Customize", "Ins WP", "Del WP"]:
                 action.setEnabled(False)
 
 
@@ -709,7 +973,7 @@ class MplTopViewCanvas(MplCanvas):
         """
         logging.debug("plotting image..")
         self.wms_image = self.map.imshow(img, interpolation="nearest", alpha=1.,
-                                         origin=PIL_image_origin)
+                                         origin=PIL_IMAGE_ORIGIN)
         # NOTE: imshow always draws the images to the lowest z-level of the
         # plot.
         # See these mailing list entries:
@@ -757,7 +1021,7 @@ class MplTopViewCanvas(MplCanvas):
                 self.legax.set_position([1 - ax_extent_x, 0.01, ax_extent_x, ax_extent_y])
 
             # Plot the new legimg in the legax axes.
-            self.legimg = self.legax.imshow(img, origin=PIL_image_origin, aspect="equal",
+            self.legimg = self.legax.imshow(img, origin=PIL_IMAGE_ORIGIN, aspect="equal",
                                             interpolation="nearest")
         self.draw()
         # required so that it is actually drawn...
@@ -842,8 +1106,8 @@ class MplTopViewWidget(MplNavBarWidget):
     """
 
     def __init__(self, parent=None):
-        super(MplTopViewWidget, self).__init__(parent=parent,
-                                               canvas=MplTopViewCanvas())
+        super(MplTopViewWidget, self).__init__(
+            sideview=False, parent=parent, canvas=MplTopViewCanvas())
         # Disable some elements of the Matplotlib navigation toolbar.
         # Available actions: Home, Back, Forward, Pan, Zoom, Subplots,
         #                    Customize, Save
@@ -1084,8 +1348,8 @@ class MplTimeSeriesViewWidget(MplNavBarWidget):
     """
 
     def __init__(self, parent=None):
-        super(MplTimeSeriesViewWidget, self).__init__(parent=parent,
-                                                      canvas=MplTimeSeriesViewCanvas())
+        super(MplTimeSeriesViewWidget, self).__init__(
+            parent=parent, canvas=MplTimeSeriesViewCanvas())
         # Disable some elements of the Matplotlib navigation toolbar.
         # Available actions: Home, Back, Forward, Pan, Zoom, Subplots,
         #                    Customize, Save
