@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -33,9 +33,10 @@ import os
 from datetime import datetime, timedelta
 import numpy as np
 
-from mslib.msui.mss_qt import QtGui, QtWidgets, USE_PYQT5
+from mslib.msui.mss_qt import QtWidgets, get_open_filename
 from mslib.msui.mss_qt import ui_satellite_dockwidget as ui
 from mslib.utils import save_settings_pickle, load_settings_pickle
+from fs import open_fs
 
 
 def read_nasa_satellite_prediction(fname):
@@ -59,7 +60,9 @@ def read_nasa_satellite_prediction(fname):
                  multiplied by -1. ******
     """
     # Read the file into a list of strings.
-    satfile = open(fname, 'r')
+    _dirname, _name = os.path.split(fname)
+    _fs = open_fs(_dirname)
+    satfile = _fs.open(_name, 'r')
     satlines = satfile.readlines()
     satfile.close()
 
@@ -131,10 +134,10 @@ class SatelliteControlWidget(QtWidgets.QWidget, ui.Ui_SatelliteDockWidget):
         """Slot that opens a file dialog to choose a file with satellite
            overpass predictions.
         """
-        filename = QtGui.QFileDialog.getOpenFileName(
+        filename = get_open_filename(
             self, "Open NASA satellite overpass prediction",
-            os.path.dirname(str(self.leFile.text())), "(*.*)")
-        filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
+            os.path.join(os.path.dirname(str(self.leFile.text()))), u"All Files (*)",
+            pickertag="filepicker_satellitetrack")
         if not filename:
             return
         self.leFile.setText(filename)
@@ -144,6 +147,9 @@ class SatelliteControlWidget(QtWidgets.QWidget, ui.Ui_SatelliteDockWidget):
         """Load the file specified in leFile and fill the combobox with the
            available track segments.
         """
+        # ToDo nappy needs filelike object first
+        # _dirname, _name = os.path.split(self.leFile.text())
+        # _fs = open_fs(_dirname)
         filename = str(self.leFile.text())
         logging.debug("loading satellite overpasses in file '%s'", filename)
 
