@@ -12,7 +12,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,7 +38,6 @@ from mslib.msui.mss_qt import QtGui, QtWidgets
 from mslib.msui.mss_qt import ui_topview_window as ui
 from mslib.msui.mss_qt import ui_topview_mapappearance as ui_ma
 from mslib.msui.viewwindows import MSSMplViewWindow
-from mslib.msui import mpl_pathinteractor as mpl_pi
 from mslib.msui import wms_control as wc
 from mslib.msui import satellite_dockwidget as sat
 from mslib.msui import remotesensing_dockwidget as rs
@@ -144,7 +143,7 @@ class MSS_TV_MapAppearanceDialog(QtWidgets.QDialog, ui_ma.Ui_MapAppearanceDialog
 
 
 class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
-    """PyQt4 window implementing a MapCanvas as an interactive flight track
+    """PyQt window implementing a MapCanvas as an interactive flight track
        editor.
     """
     name = "Top View"
@@ -178,15 +177,6 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         # Tool opener.
         self.cbTools.currentIndexChanged.connect(self.openTool)
 
-        # Controls to interact with the flight track.
-        # (For usage of the functools.partial() function, see Chapter 4 (Section
-        # Signals and Slots) of 'Rapid GUI Programming with Python and Qt: The
-        # Definitive Guide to PyQt Programming' (Mark Summerfield).)
-        wpi = self.mpl.canvas.waypoints_interactor
-        self.btMvWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.MOVE))
-        self.btInsWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.INSERT))
-        self.btDelWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.DELETE))
-
     def __del__(self):
         del self.mpl.canvas.waypoints_interactor
 
@@ -202,8 +192,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         self.cbChangeMapSection.clear()
         predefined_map_sections = config_loader(dataset="predefined_map_sections",
                                                 default=mss_default.predefined_map_sections)
-        items = list(predefined_map_sections.keys())
-        items.sort()
+        items = sorted(predefined_map_sections.keys())
         self.cbChangeMapSection.addItems(items)
 
         # Initialise the map and the flight track. Get the initial projection
