@@ -356,7 +356,15 @@ class WMSMapFetcher(QtCore.QObject):
             logging.debug("Retrieving legend from '%s'", urlstr)
             urlobject = requests.get(urlstr)
             image_io = io.BytesIO(urlobject.content)
-            legend_img_raw = PIL.Image.open(image_io)
+            try:
+                legend_img_raw = PIL.Image.open(image_io)
+            except Exception as ex:
+                # This exception may be triggered if there was a problem with the legend
+                # as present with http://geoservices.knmi.nl/cgi-bin/HARM_N25.cgi
+                # it is deemed preferential to display the WMS map and forget about the
+                # legend than not displaying anything.
+                logging.error("Wildecard Exception %s - %s.", type(ex), ex)
+                return None
             legend_img = legend_img_raw.crop(legend_img_raw.getbbox())
             # Store the retrieved image in the cache, if enabled.
             try:
@@ -895,6 +903,10 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
                 # IBL web map service.
                 self.init_time_name = "run"
                 enable_inittime = True
+            elif "reference_time" in lobj.dimensions and "reference_time" in lobj.extents:
+                # To support http://geoservices.knmi.nl/cgi-bin/HARM_N25.cg
+                self.init_time_name = "reference_time"
+                enable_inittime = True
 
             # Initialisation tag was found: Try to determine the format of
             # the date/time strings and read the provided extent values.
@@ -926,7 +938,6 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
 
         lobj = layerobj
         while lobj is not None:
-
             if "time" in lobj.dimensions and "time" in lobj.extents:
                 self.valid_time_name = "time"
                 enable_validtime = True
@@ -938,6 +949,10 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
                 # IBL web map service.
                 self.valid_time_name = "forecast"
                 enable_validtime = True
+            elif "time" in lobj.extents:
+                # fix for capability document of https://neowms.sci.gsfc.nasa.gov/wms/wms
+                self.valid_time_name = "time"
+                enable_validtime = True
 
             # Both time dimension and time extent tags were found. Try to determine the
             # format of the date/time strings.
@@ -1423,7 +1438,9 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
             return
 
         valid_time = self.get_valid_time()
-        if valid_time is not None and valid_time not in self.allowed_valid_times:
+        if (valid_time is not None and
+                self.allowed_valid_times is not None and
+                valid_time not in self.allowed_valid_times):
             QtWidgets.QMessageBox.critical(self, self.tr("Web Map Service"),
                                            self.tr("ERROR: Invalid valid time chosen!\n"
                                                    "(watch out for the strikethrough)!"))
