@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -148,7 +148,6 @@ class DefaultDataAccess(NWPDataAccess):
         """
         assert self._filetree is not None, "filetree is None. Forgot to call setup()?"
         try:
-            print(variable, vartype, self._filetree[vartype][init_time][variable][valid_time])
             return self._filetree[vartype][init_time][variable][valid_time]
         except KeyError as ex:
             self.setup()
@@ -239,7 +238,7 @@ class DefaultDataAccess(NWPDataAccess):
                 var_leaf = leaf.setdefault(standard_name, {})
                 for valid_time in valid_times:
                     if valid_time in var_leaf:
-                        logging.warn(
+                        logging.warning(
                             "some data was found twice! vartype='%s' init_time='%s' standard_name='%s' "
                             "valid_time='%s' first_file='%s' second_file='%s'",
                             vert_type, init_time, standard_name, valid_time, var_leaf[valid_time], filename)
@@ -253,14 +252,14 @@ class DefaultDataAccess(NWPDataAccess):
         """
         init_times = set(itertools.chain.from_iterable(
             self._filetree[_x].keys() for _x in self._filetree))
-        return sorted(list(init_times))
+        return sorted(init_times)
 
     def get_valid_times(self, variable, vartype, init_time):
         """Returns a list of available valid times for the specified
            variable at the specified init time.
         """
         try:
-            return sorted(list(self._filetree[vartype][init_time][variable].keys()))
+            return sorted(self._filetree[vartype][init_time][variable].keys())
         except KeyError as ex:
             logging.error("Could not find times! %s %s", type(ex), ex)
             return []
@@ -275,7 +274,7 @@ class DefaultDataAccess(NWPDataAccess):
         for init_time in self._filetree[vartype]:
             if variable in self._filetree[vartype][init_time]:
                 all_valid_times.extend(list(self._filetree[vartype][init_time][variable].keys()))
-        return sorted(list(set(all_valid_times)))
+        return sorted(set(all_valid_times))
 
     def get_all_datafiles(self):
         """Return a list of all available data files.
