@@ -10,7 +10,7 @@
     This file is part of mss.
 
     :copyright: Copyright 2017 Andreas Hilboll
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -70,5 +70,5 @@ MSSChemQuantities = \
 
 MSSChemTargets = {
     qtylong + '_of_' + species + '_in_air': (key, qty, units, scale)
-    for key, species in list(MSSChemSpecies.items())
-    for qty, (qtylong, units, scale) in list(MSSChemQuantities.items())}
+    for key, species in MSSChemSpecies.items()
+    for qty, (qtylong, units, scale) in MSSChemQuantities.items()}
