@@ -512,23 +512,18 @@ app = WMSServer()
 
 def application(environ, start_response):
     try:
-        # Request info
         query = CaseInsensitiveMultiDict(paste.request.parse_dict_querystring(environ))
         logging.debug(u"ENVIRON: %s", environ)
-
-        # Processing
         request = query.get('request')
         output = ""
         return_format = 'text/plain'
+        status = '200 OK'
 
         url = paste.request.construct_url(environ)
         server_url = urllib.parse.urljoin(url, urllib.parse.urlparse(url).path)
 
         if request is None:
-            server_url = "{}?service=WMS&request=GetCapabilities&version=1.1.1".format(server_url)
-            return_format = 'text/xml'
-            return_data = app.get_capabilities(server_url)
-            output = return_data.encode('utf-8')
+            status = '404 Not Found'
         elif request.lower() == 'getcapabilities':
             return_format = 'text/xml'
             return_data = app.get_capabilities(server_url)
@@ -540,11 +535,10 @@ def application(environ, start_response):
                 return_format = return_format.lower()  # MAYBE TO BE DELETED
                 output = return_data
             else:
+                status = '404 Not Found'
                 return_format = "text/xml"
                 output = return_data.encode('utf-8')
 
-        # Preparing the Response
-        status = '200 OK'
         response_headers = [('Content-type', return_format), ('Content-Length', str(len(output)))]
         start_response(status, response_headers)
 
@@ -556,6 +550,7 @@ def application(environ, start_response):
         # ToDo add a config var to disable output, replace by standard text, "Internal Server error"
         error_message = error_message + "\n" + traceback.format_exc()
         logging.error(error_message)
+        error_message = error_message.encode("utf-8")
 
         response_headers = [('Content-type', 'text/plain'),
                             ('Content-Length', str(len(error_message)))]
