@@ -27,6 +27,7 @@
 """
 
 import glob
+import numpy as np
 import netCDF4
 
 
@@ -142,6 +143,10 @@ def num2date(times, units, calendar='standard'):
 
     Refer to netCDF4.num2date() for further documentation.
     """
+    # Patch to adress the problem of netCDF4.num2date not being able
+    # to handle masked array without a mask.
+    if hasattr(times, "mask") and times.mask is np.ma.nomask:
+        times = times.data
     return netCDF4.num2date(times, units, calendar=calendar)
 
 
